.. default-intersphinx:: django1.6 djblets1.0


============================
Djblets 1.0.17 Release Notes
============================

**Release date**: April 13, 2021


New Features
============

* Added a ``settings.LOGGING_TO_STDOUT`` setting, which can be set to ``True``
  to force all log messages to go to standard out.

  This is useful particularly when running in a Docker container, where
  applications are expected to log to standard output. This can be used along
  with the standard file-based logging.

  This is a backport from :doc:`Djblets 2.2 <2.2>`.


Contributors
============

* Christian Hammond
